pub trait ToJson {
// Required method
fn to_json_string(&self) -> String;
}Expand description
Trait that converts a type to a JSON string.
This trait has a derive macro.
Required Methods
Sourcefn to_json_string(&self) -> String
fn to_json_string(&self) -> String
Converts self to a JSON string.
Implementations of this should not fail.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl ToJson for str
FIXME: this doesn’t correctly handle newlines
and other escaped characters like "
impl ToJson for str
FIXME: this doesn’t correctly handle newlines
and other escaped characters like "
fn to_json_string(&self) -> String
Sourceimpl<A> ToJson for (A,)where
A: ToJson,
ToJson is implemented for tuples up to size 12.
impl<A> ToJson for (A,)where
A: ToJson,
ToJson is implemented for tuples up to size 12.